# Methods List

<table>
	<tr align="center">
		<th>Title</th>
		<th>Code</th>
		<th>Ratio</th>
		<th>Water(gr)</th>
		<th>Version</th>
	</tr>
	<tr align="center">
		<td>Custom</td>
		<td><code>custom</code></td>
		<td>1/17</td>
		<td>240</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>V60</td>
		<td><code>v60</code></td>
		<td>3/50</td>
		<td>250</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Chemex</td>
		<td><code>chemex</code></td>
		<td>1/15</td>
		<td>240</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Espresso</td>
		<td><code>espresso</code></td>
		<td>1/2</td>
		<td>36</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>French press</td>
		<td><code>french-press</code></td>
		<td>1/15</td>
		<td>120</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Siphon</td>
		<td><code>siphon</code></td>
		<td>1/15</td>
		<td>240</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Pour-over</td>
		<td><code>pour-over</code></td>
		<td>1/15</td>
		<td>240</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Auto drip</td>
		<td><code>auto-drip</code></td>
		<td>1/16</td>
		<td>128</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Cold brew</td>
		<td><code>cold-brew</code></td>
		<td>1/11</td>
		<td>242</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Cold brew concentrate</td>
		<td><code>cold-brew-conc</code></td>
		<td>1/5</td>
		<td>120</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Moka pot</td>
		<td><code>moka-pot</code></td>
		<td>1/10</td>
		<td>60</td>
		<td>>=0.2</td>
	</tr>
</table>


